@@ -84,6 +84,7 @@ def getFreePorts(openPort=None):
 class KUTTYPY:	
 	VERSIONNUM = Byte.pack(99)
 	VERSIONNUM_328P = Byte.pack(100)
+	VERSIONNUM_UNO = Byte.pack(101)
 	GET_VERSION = Byte.pack(1)
 	READB =   Byte.pack(2)
 	WRITEB =   Byte.pack(3)
@@ -310,9 +311,9 @@ class KUTTYPY:
 
 
 	def __get_version__(self,fd):
-		fd.setRTS(0)
-		time.sleep(0.01)
-		fd.setRTS(1)
+		fd.setRTS(0);fd.setDTR(0);
+		time.sleep(0.01);
+		fd.setRTS(1);fd.setDTR(1);
 		time.sleep(0.25)
 		while fd.in_waiting:
 			fd.read(fd.in_waiting)
@@ -370,9 +371,9 @@ class KUTTYPY:
 		if len(version)==1:
 			if ord(version)==ord(self.VERSIONNUM):
 				return fd,ord(version),True
-			if ord(version)==ord(self.VERSIONNUM_328P):
+			elif ord(version)in [ ord(self.VERSIONNUM_328P), ord(self.VERSIONNUM_UNO)]: #assume it is mega32. will work with glitches
 				self.nano = True
-				return fd,ord(version),True
+				return fd,ord(self.VERSIONNUM),True
 		print ('version check failed',len(version),ord(version))
 		return None,'',False
 		
