@@ -632,16 +632,25 @@ class AppWindow(QtWidgets.QMainWindow, layout.Ui_MainWindow):
 						if self.fname[-2:] in ['.c','.C','.s','.S']:
 							self.fname = self.fname[:-2]+'.hex' #Replace .c with .hex
 						self.logThis.emit('''<span style="font-size:12pt">Upload Code... Trigger Reset...</span>''')
-						self.p.fd.setRTS(0);time.sleep(0.01);self.p.fd.setRTS(1);time.sleep(0.4)
+						self.p.fd.setRTS(0);self.p.fd.setDTR(0);
+						time.sleep(0.01);
+						self.p.fd.setRTS(1);self.p.fd.setDTR(1);
+						time.sleep(0.05)
 						dude = uploader.Uploader(self.p.fd, hexfile=self.fname,logger = self.logThis)
 						dude.program()
 						dude.verify()
-						self.p.fd.setRTS(0);time.sleep(0.01);self.p.fd.setRTS(1);time.sleep(0.2)
+						self.p.fd.setRTS(0);self.p.fd.setDTR(0);
+						time.sleep(0.01);
+						self.p.fd.setRTS(1);self.p.fd.setDTR(1);
+						time.sleep(0.25)
 						self.p.get_version()
 						self.logThis.emit('''<span style="color:darkgreen;">Finished upload</span>''')
 					except Exception as err:
 						print('upload error',err)
-						self.p.fd.setRTS(0);time.sleep(0.01);self.p.fd.setRTS(1);time.sleep(0.2)
+						self.p.fd.setRTS(0);self.p.fd.setDTR(0);
+						time.sleep(0.01);
+						self.p.fd.setRTS(1);self.p.fd.setDTR(1);
+						time.sleep(0.25)
 						self.p.get_version()
 						self.logThis.emit('''<span style="color:darkred;">Failed to upload</span>''')
 						#self.jumpToApplication(False) #Force a reset
@@ -797,10 +806,10 @@ class AppWindow(QtWidgets.QMainWindow, layout.Ui_MainWindow):
 
 			else:
 				self.serialGuageButton.hide()
-				self.p.fd.setRTS(0)  #Trigger a reset
-				time.sleep(0.01)
-				self.p.fd.setRTS(1)
-				time.sleep(0.1)
+				self.p.fd.setRTS(0);self.p.fd.setDTR(0);
+				time.sleep(0.01);
+				self.p.fd.setRTS(1);self.p.fd.setDTR(1);
+				time.sleep(0.2)
 				while self.p.fd.in_waiting:
 					self.p.fd.read()
 				self.p.get_version()
@@ -825,6 +834,8 @@ class AppWindow(QtWidgets.QMainWindow, layout.Ui_MainWindow):
 		menu.addAction('Save Window as Svg', self.exportSvg)
 		menu.addAction('Open Stepper Controller', self.newStepperController)
 
+		menu.addAction('Upload Hex File', self.uploadHex)
+
 		#Theme
 		'''
 		self.themeAction = QtWidgets.QWidgetAction(menu)
@@ -850,9 +861,6 @@ class AppWindow(QtWidgets.QMainWindow, layout.Ui_MainWindow):
 		#self.userApplication.toggled['bool'].connect(self.jumpToApplication)
 		#self.statusBar.addPermanentWidget(self.userApplication)
 
-		#self.hexUploadButton = QtWidgets.QPushButton("Upload Hex");
-		#self.hexUploadButton.clicked.connect(self.uploadHex)
-		#self.statusBar.addPermanentWidget(self.hexUploadButton)
 
 
 		self.speedbutton = QtWidgets.QComboBox(); self.speedbutton.addItems(['Slow','Fast','Ultra']);
@@ -1012,13 +1020,6 @@ def run():
 	myapp = AppWindow(app=app, path=path)
 	myapp.show()
 	r = app.exec_()
-	'''
-	if myapp.p.connected:
-		myapp.p.fd.write(b'j')
-		#myapp.p.fd.setRTS(0)
-		#time.sleep(0.01)
-		#myapp.p.fd.setRTS(1)
-	'''
 	app.deleteLater()
 	sys.exit(r)
 
